@@ -24,19 +24,19 @@ from urllib.parse import quote
 import deprecation
 import numpy as np
 import pandas as pd
+from more_itertools import unique_everseen
+
 from gs_quant.api.gs.assets import GsAssetApi
 from gs_quant.api.gs.portfolios import GsPortfolioApi
 from gs_quant.base import InstrumentBase
-from gs_quant.common import RiskMeasure
+from gs_quant.common import RiskMeasure, RiskPosition
 from gs_quant.instrument import Instrument, AssetType
 from gs_quant.markets import HistoricalPricingContext, OverlayMarket, PricingContext, PositionContext
 from gs_quant.priceable import PriceableImpl
 from gs_quant.risk import ResolvedInstrumentValues
 from gs_quant.risk.results import CompositeResultFuture, PortfolioRiskResult, PortfolioPath, PricingFuture
-from gs_quant.target.common import RiskPosition
 from gs_quant.target.portfolios import Portfolio as MarqueePortfolio
 from gs_quant.target.portfolios import Position, PositionSet, RiskRequest, PricingDateAndMarketDataAsOf
-from more_itertools import unique_everseen
 
 _logger = logging.getLogger(__name__)
 
@@ -72,6 +72,15 @@ class Portfolio(PriceableImpl):
         self.__id = None
         self.__quote_id = None
 
+    def __repr__(self):
+        name = 'Portfolio'
+        inst_desc = f'{len(self.all_instruments) if self.priceables else "0"} instrument(s)'
+        if self.name:
+            name += f'({self.name}, {inst_desc})'
+        else:
+            name += f'({inst_desc})'
+        return name
+
     def _to_records(self):
         def get_name(obj, idx):
             if isinstance(obj, InstrumentBase) and hasattr(obj, 'type_'):
@@ -249,7 +258,8 @@ class Portfolio(PriceableImpl):
     @classmethod
     def get(cls,
             portfolio_id: str = None,
-            portfolio_name: str = None):
+            portfolio_name: str = None,
+            query_instruments: Optional[bool] = False):
         if portfolio_name:
             portfolio = GsPortfolioApi.get_portfolio_by_name(portfolio_name)
             portfolio_id = portfolio.id
@@ -257,7 +267,8 @@ class Portfolio(PriceableImpl):
         portfolio = GsPortfolioApi.get_portfolio(portfolio_id)
         ret = Portfolio(name=portfolio.name)
         ret.__id = portfolio_id
-        ret._get_instruments(position_date, True)
+        if query_instruments:
+            ret._get_instruments(position_date, True)
         return ret
 
     @classmethod
@@ -444,7 +455,7 @@ class Portfolio(PriceableImpl):
     def to_csv(self, csv_file: str, mappings: Optional[dict] = None, ignored_cols: Optional[list] = None):
         port_df = self.to_frame(mappings or {})
         port_df = port_df[np.setdiff1d(port_df.columns, ignored_cols or [])]
-        port_df.reset_index(drop=True, inplace=True)
+        port_df = port_df.reset_index(drop=True)
 
         port_df.to_csv(csv_file)
 
@@ -596,3 +607,26 @@ class Portfolio(PriceableImpl):
         portfolio_clone.__id = self.__id
         portfolio_clone.__quote_id = self.__quote_id
         return portfolio_clone
+
+
+@dataclass
+class Grid(Portfolio):
+    """A grid of instruments
+
+    A grid is a type of portfolio which represents a grid of similar instruments
+
+    """
+
+    def __init__(self,
+                 priceable: PriceableImpl,
+                 x_param: str,
+                 x_values: Iterable,
+                 y_param: str,
+                 y_values: Iterable,
+                 name: Optional[str] = None):
+
+        x_overrides = [{x_param: v,
+                        'name': v} for v in x_values]
+        y_overrides = [{y_param: v} for v in y_values]
+        super().__init__([Portfolio([priceable.clone(**{**x, **y}) for x in x_overrides], name=next(iter(y.values())))
+                          for y in y_overrides], name)
