@@ -14,17 +14,28 @@ specific language governing permissions and limitations
 under the License.
 """
 
+import datetime as dt
+
+import numpy as np
+import pandas as pd
 import pytest
-from gs_quant.timeseries import *
-from gs_quant.timeseries.statistics import Direction
+import scipy.stats.mstats as stats
 from pandas.testing import assert_series_equal
 from scipy.integrate import odeint
 
+from gs_quant.data import DataContext
+from gs_quant.errors import MqTypeError, MqValueError, MqError
+from gs_quant.timeseries import normalize_window, Window, Returns, returns
+from gs_quant.timeseries.statistics import (Direction, generate_series, LinearRegression, RollingLinearRegression,
+                                            min_, max_, range_, mean, median, mode, sum_, product, std, exponential_std,
+                                            var, cov, zscores, winsorize, percentiles, percentile, SIRModel, SEIRModel)
+
 
 def _random_series(days=365, nans=10):
     assert nans < days
-    values = np.random.random(days)
-    nan_indexes = np.floor(np.random.random(nans) * len(values)).astype(np.int_)
+    rng = np.random.default_rng()
+    values = rng.random(days)
+    nan_indexes = np.floor(rng.random(nans) * len(values)).astype(np.int_)
     for i in nan_indexes:
         values[i] = np.nan
 
@@ -44,23 +55,23 @@ def test_generate_series():
     x = generate_series(100)
 
     assert (len(x) == 100)
-    assert (x.index[0] == datetime.date.today())
-    assert (x[0] == 100)
+    assert (x.index[0] == dt.date.today())
+    assert (x.iloc[0] == 100)
 
     x = generate_series(100, Direction.END_TODAY)
     assert (len(x) == 100)
-    assert (x.index[-1] == datetime.date.today())
-    assert (x[0] == 100)
+    assert (x.index[-1] == dt.date.today())
+    assert (x.iloc[0] == 100)
 
 
 def test_min():
     dates = [
-        date(2019, 1, 1),
-        date(2019, 1, 2),
-        date(2019, 1, 3),
-        date(2019, 1, 4),
-        date(2019, 1, 7),
-        date(2019, 1, 8),
+        dt.date(2019, 1, 1),
+        dt.date(2019, 1, 2),
+        dt.date(2019, 1, 3),
+        dt.date(2019, 1, 4),
+        dt.date(2019, 1, 7),
+        dt.date(2019, 1, 8),
     ]
 
     x = pd.Series([3.0, 2.0, 3.0, 1.0, 3.0, 6.0], index=dates)
@@ -109,12 +120,12 @@ def test_min():
 
 def test_max():
     dates = [
-        date(2019, 1, 1),
-        date(2019, 1, 2),
-        date(2019, 1, 3),
-        date(2019, 1, 4),
-        date(2019, 1, 7),
-        date(2019, 1, 8),
+        dt.date(2019, 1, 1),
+        dt.date(2019, 1, 2),
+        dt.date(2019, 1, 3),
+        dt.date(2019, 1, 4),
+        dt.date(2019, 1, 7),
+        dt.date(2019, 1, 8),
     ]
 
     x = pd.Series([3.0, 2.0, 3.0, 1.0, 3.0, 6.0], index=dates)
@@ -162,12 +173,12 @@ def test_max():
 
 def test_range():
     dates = [
-        date(2019, 1, 1),
-        date(2019, 1, 2),
-        date(2019, 1, 3),
-        date(2019, 1, 4),
-        date(2019, 1, 7),
-        date(2019, 1, 8),
+        dt.date(2019, 1, 1),
+        dt.date(2019, 1, 2),
+        dt.date(2019, 1, 3),
+        dt.date(2019, 1, 4),
+        dt.date(2019, 1, 7),
+        dt.date(2019, 1, 8),
     ]
 
     x = pd.Series([3.0, 2.0, 3.0, 1.0, 3.0, 6.0], index=dates)
@@ -191,12 +202,12 @@ def test_range():
 
 def test_mean():
     dates = [
-        date(2019, 1, 1),
-        date(2019, 1, 2),
-        date(2019, 1, 3),
-        date(2019, 1, 4),
-        date(2019, 1, 7),
-        date(2019, 1, 8),
+        dt.date(2019, 1, 1),
+        dt.date(2019, 1, 2),
+        dt.date(2019, 1, 3),
+        dt.date(2019, 1, 4),
+        dt.date(2019, 1, 7),
+        dt.date(2019, 1, 8),
     ]
 
     x = pd.Series([3.0, 2.0, 3.0, 1.0, 3.0, 6.0], index=dates)
@@ -233,12 +244,12 @@ def test_mean():
 
 def test_median():
     dates = [
-        date(2019, 1, 1),
-        date(2019, 1, 2),
-        date(2019, 1, 3),
-        date(2019, 1, 4),
-        date(2019, 1, 7),
-        date(2019, 1, 8),
+        dt.date(2019, 1, 1),
+        dt.date(2019, 1, 2),
+        dt.date(2019, 1, 3),
+        dt.date(2019, 1, 4),
+        dt.date(2019, 1, 7),
+        dt.date(2019, 1, 8),
     ]
 
     x = pd.Series([3.0, 2.0, 3.0, 1.0, 3.0, 6.0], index=dates)
@@ -264,12 +275,12 @@ def test_median():
 
 def test_mode():
     dates = [
-        date(2019, 1, 1),
-        date(2019, 1, 2),
-        date(2019, 1, 3),
-        date(2019, 1, 4),
-        date(2019, 1, 7),
-        date(2019, 1, 8),
+        dt.date(2019, 1, 1),
+        dt.date(2019, 1, 2),
+        dt.date(2019, 1, 3),
+        dt.date(2019, 1, 4),
+        dt.date(2019, 1, 7),
+        dt.date(2019, 1, 8),
     ]
 
     x = pd.Series([3.0, 2.0, 3.0, 1.0, 3.0, 6.0], index=dates)
@@ -300,12 +311,12 @@ def test_mode():
 
 def test_sum():
     dates = [
-        date(2019, 1, 1),
-        date(2019, 1, 2),
-        date(2019, 1, 3),
-        date(2019, 1, 4),
-        date(2019, 1, 7),
-        date(2019, 1, 8),
+        dt.date(2019, 1, 1),
+        dt.date(2019, 1, 2),
+        dt.date(2019, 1, 3),
+        dt.date(2019, 1, 4),
+        dt.date(2019, 1, 7),
+        dt.date(2019, 1, 8),
     ]
 
     x = pd.Series([1.0, 2.0, 3.0, 4.0, 5.0, 6.0], index=dates)
@@ -334,12 +345,12 @@ def test_sum():
 
 def test_product():
     dates = [
-        date(2019, 1, 1),
-        date(2019, 1, 2),
-        date(2019, 1, 3),
-        date(2019, 1, 4),
-        date(2019, 1, 7),
-        date(2019, 1, 8),
+        dt.date(2019, 1, 1),
+        dt.date(2019, 1, 2),
+        dt.date(2019, 1, 3),
+        dt.date(2019, 1, 4),
+        dt.date(2019, 1, 7),
+        dt.date(2019, 1, 8),
     ]
 
     x = pd.Series([1.0, 2.0, 3.0, 4.0, 5.0, 6.0], index=dates)
@@ -361,12 +372,12 @@ def test_product():
 
 def test_std():
     dates = [
-        date(2019, 1, 1),
-        date(2019, 1, 2),
-        date(2019, 1, 3),
-        date(2019, 1, 4),
-        date(2019, 1, 7),
-        date(2019, 1, 8),
+        dt.date(2019, 1, 1),
+        dt.date(2019, 1, 2),
+        dt.date(2019, 1, 3),
+        dt.date(2019, 1, 4),
+        dt.date(2019, 1, 7),
+        dt.date(2019, 1, 8),
     ]
 
     x = pd.Series([3.0, 2.0, 3.0, 1.0, 3.0, 6.0], index=dates)
@@ -396,17 +407,17 @@ def test_exponential_std():
             ema = sum(weights * x) / sum(weights)
             debias_fact = sum(weights) ** 2 / (sum(weights) ** 2 - sum(weights ** 2))
             var = debias_fact * sum(weights * (x - ema) ** 2) / sum(weights)
-            std[i] = np.sqrt(var)
-        std[0] = np.NaN
+            std.iloc[i] = np.sqrt(var)
+        std.iloc[0] = np.nan
         return std
 
     dates = [
-        date(2019, 1, 1),
-        date(2019, 1, 2),
-        date(2019, 1, 3),
-        date(2019, 1, 4),
-        date(2019, 1, 7),
-        date(2019, 1, 8),
+        dt.date(2019, 1, 1),
+        dt.date(2019, 1, 2),
+        dt.date(2019, 1, 3),
+        dt.date(2019, 1, 4),
+        dt.date(2019, 1, 7),
+        dt.date(2019, 1, 8),
     ]
 
     x = pd.Series([3.0, 2.0, 3.0, 1.0, 3.0, 6.0], index=dates)
@@ -422,12 +433,12 @@ def test_exponential_std():
 
 def test_var():
     dates = [
-        date(2019, 1, 1),
-        date(2019, 1, 2),
-        date(2019, 1, 3),
-        date(2019, 1, 4),
-        date(2019, 1, 7),
-        date(2019, 1, 8),
+        dt.date(2019, 1, 1),
+        dt.date(2019, 1, 2),
+        dt.date(2019, 1, 3),
+        dt.date(2019, 1, 4),
+        dt.date(2019, 1, 7),
+        dt.date(2019, 1, 8),
     ]
 
     x = pd.Series([3.0, 2.0, 3.0, 1.0, 3.0, 6.0], index=dates)
@@ -449,12 +460,12 @@ def test_var():
 
 def test_cov():
     dates = [
-        date(2019, 1, 1),
-        date(2019, 1, 2),
-        date(2019, 1, 3),
-        date(2019, 1, 4),
-        date(2019, 1, 7),
-        date(2019, 1, 8),
+        dt.date(2019, 1, 1),
+        dt.date(2019, 1, 2),
+        dt.date(2019, 1, 3),
+        dt.date(2019, 1, 4),
+        dt.date(2019, 1, 7),
+        dt.date(2019, 1, 8),
     ]
 
     x = pd.Series([3.0, 2.0, 3.0, 1.0, 3.0, 6.0], index=dates)
@@ -484,12 +495,12 @@ def test_zscores():
     assert_series_equal(zscores(pd.Series([1]), Window(1, 0)), pd.Series([0.0]))
 
     dates = [
-        date(2019, 1, 1),
-        date(2019, 1, 2),
-        date(2019, 1, 3),
-        date(2019, 1, 4),
-        date(2019, 1, 7),
-        date(2019, 1, 8),
+        dt.date(2019, 1, 1),
+        dt.date(2019, 1, 2),
+        dt.date(2019, 1, 3),
+        dt.date(2019, 1, 4),
+        dt.date(2019, 1, 7),
+        dt.date(2019, 1, 8),
     ]
 
     x = pd.Series([3.0, 2.0, 3.0, 1.0, 3.0, 6.0], index=dates)
@@ -514,7 +525,7 @@ def test_zscores():
     assert_series_equal(result, expected, obj='z-score window string 1w')
 
     result = zscores(x, '1m')
-    expected = pd.Series(dtype=float)
+    expected = pd.Series(dtype=float, index=[])
     assert_series_equal(result, expected, obj="z-score window too large")
 
 
@@ -544,16 +555,17 @@ def test_winsorize():
 
 def test_percentiles():
     dates = [
-        date(2019, 1, 1),
-        date(2019, 1, 2),
-        date(2019, 1, 3),
-        date(2019, 1, 4),
-        date(2019, 1, 7),
-        date(2019, 1, 8),
+        dt.date(2019, 1, 1),
+        dt.date(2019, 1, 2),
+        dt.date(2019, 1, 3),
+        dt.date(2019, 1, 4),
+        dt.date(2019, 1, 7),
+        dt.date(2019, 1, 8),
     ]
 
     x = pd.Series([3.0, 2.0, 3.0, 1.0, 3.0, 6.0], index=dates)
     y = pd.Series([3.5, 1.8, 2.9, 1.2, 3.1, 6.0], index=dates)
+    y_with_mismatched_index = pd.Series([3.5, 1.8, 2.9, 1.2, 3.1], index=dates[:-1])
 
     assert_series_equal(percentiles(pd.Series(dtype=float), y), pd.Series(dtype=float))
     assert_series_equal(percentiles(x, pd.Series(dtype=float)), pd.Series(dtype=float))
@@ -567,6 +579,10 @@ def test_percentiles():
     expected = pd.Series([100.0, 0.0, 50.0, 50.0, 100.0, 75.0], index=dates)
     assert_series_equal(result, expected, obj="percentiles with window 2 and ramp 0")
 
+    result = percentiles(x, y_with_mismatched_index, Window(2, 0))
+    expected = pd.Series([100.0, 0.0, 50.0, 50.0, 100.0], index=dates[:-1])
+    assert_series_equal(result, expected, obj="percentiles with mismatched y index")
+
     result = percentiles(x, y, Window('1w', 0))
     expected = pd.Series([100.0, 0.0, 33.333333, 25.0, 100.0, 90.0], index=dates)
     assert_series_equal(result, expected, obj="percentiles with window 1w")
@@ -575,6 +591,10 @@ def test_percentiles():
     expected = pd.Series([25.0, 100.0, 90.0], index=dates[3:])
     assert_series_equal(result, expected, obj="percentiles with window 1w and ramp 3d")
 
+    result = percentiles(x, y, Window(5, '3d'))
+    expected = pd.Series([25.0, 100.0, 90.0], index=dates[3:])
+    assert_series_equal(result, expected, obj="percentiles with window 5 and ramp 3d")
+
     result = percentiles(x)
     expected = pd.Series([50.0, 25.0, 66.667, 12.500, 70.0, 91.667], index=dates)
     assert_series_equal(result, expected, obj="percentiles over historical values")
@@ -606,11 +626,11 @@ def test_percentile():
 
 
 def test_percentile_str():
-    today = datetime.datetime.now()
+    today = dt.datetime.now()
     days = pd.date_range(today, periods=12, freq='D')
     start = pd.Series([29, 56, 82, 13, 35, 53, 25, 23, 21, 12, 15, 9], index=days)
     actual = percentile(start, 2, '10d')
-    expected = pd.Series([12.18, 9.54], index=pd.date_range(today + datetime.timedelta(days=10), periods=2, freq='D'))
+    expected = pd.Series([12.18, 9.54], index=pd.date_range(today + dt.timedelta(days=10), periods=2, freq='D'))
     assert_series_equal(actual, expected)
 
     actual = percentile(start, 50, '1w')
@@ -637,7 +657,7 @@ def test_regression():
     expected = pd.Series([10.0, 14.0, 20.0, 28.0, 38.0, 50.0], index=pd.date_range('2019-1-1', periods=6))
     assert_series_equal(regression.fitted_values(), expected)
 
-    dates_predict = [date(2019, 2, 1), date(2019, 2, 2)]
+    dates_predict = [dt.date(2019, 2, 1), dt.date(2019, 2, 2)]
     predicted = regression.predict([pd.Series([2.0, 3.0], index=dates_predict),
                                     pd.Series([6.0, 7.0], index=dates_predict)])
     expected = pd.Series([30.0, 34.0], index=dates_predict)
@@ -738,7 +758,7 @@ def test_sir_model():
     sir1 = SIRModel(beta, gamma, s, i, r, n, fit=False)
 
     with DataContext(end=dt.date.today() + dt.timedelta(days=d - 1)):
-        sir2 = SIRModel(beta, gamma, s[0], i, r[0], n, fit=False)
+        sir2 = SIRModel(beta, gamma, s.iloc[0], i, r.iloc[0], n, fit=False)
 
     assert sir1.beta() == sir1.beta()
     assert sir2.gamma() == sir2.gamma()
@@ -809,7 +829,7 @@ def test_seir_model():
     seir1 = SEIRModel(beta, gamma, sigma, s, e, i, r, n, fit=False)
 
     with DataContext(end=dt.date.today() + dt.timedelta(days=d - 1)):
-        seir2 = SEIRModel(beta, gamma, sigma, s[0], e[0], i, r[0], n, fit=False)
+        seir2 = SEIRModel(beta, gamma, sigma, s.iloc[0], e.iloc[0], i, r.iloc[0], n, fit=False)
 
     assert seir1.beta() == seir1.beta()
     assert seir2.gamma() == seir2.gamma()
